@@ -46,6 +46,31 @@
 
 <dl>
 
+<dt><b>4.7.8</b> - <i>March 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.9 (SQLite version 3.38.1)</i><br>
+
+</dd>
+<dt><b>4.7.7</b> - <i>February 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.8 (SQLite version 3.38.0)</i><br>
+
+</dd>
+<dt><b>4.7.6</b> - <i>January 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.7 (SQLite version 3.37.2)</i><br>
+
+</dd>
+<dt><b>4.7.5</b> - <i>November 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.5 (SQLite version 3.37.0)</i><br>
+
+</dd>
+<dt><b>4.7.4</b> - <i>July 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.4 (SQLite version 3.36.0)</i><br>
+
+</dd>
 <dt><b>4.7.3</b> - <i>June 2021</i></dt>
 <dd>
 Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.3 (SQLite version 3.36.0)</i><br>
